import {
  geoNaturalEarth1,
  geoPath,
  geoGraticule,
} from 'd3';
import { useMemo } from 'react';

const projection = geoNaturalEarth1();
const path = geoPath(projection);
const graticule = geoGraticule();

export const Marks = ({
  worldAtlas: { land, interiors },
  migrants,
  sizeScale,
  sizeValue,
  xAxisTickFormat,
}) => (
  <g className="marks">
    {useMemo(
      () => (
        <>
          <path
            className="sphere"
            d={path({ type: 'Sphere' })}
          />
          <path
            className="graticules"
            d={path(graticule())}
          />
          {land.features.map((feature) => (
            <path className="land" d={path(feature)}>
              <title>{feature.properties.name}</title>
            </path>
          ))}
          <path className="interiors" d={path(interiors)} />
        </>
      ),
      [land, interiors, path, graticule]
    )}
    {useMemo(
      () =>
        migrants.map((d) => {
          const [x, y] = projection([d.lng, d.lat]);
          return (
            <circle
              opacity="0.5"
              fill={'white'}
              cx={x}
              cy={y}
              r={sizeScale(sizeValue(d))}
            >
              <title>{`${xAxisTickFormat(d.time)}\n${
                d.total
              }\nLng: ${d.lng}\nLat: ${d.lat}`}</title>
            </circle>
          );
        }),
      [migrants, projection, sizeScale, xAxisTickFormat]
    )}
  </g>
);
