import React, { useState } from 'react';
import ReactDOM from 'react-dom';
import { useWorldAtlas } from './useWorldAtlas';
import { useMigrants } from './useMigrants';
import { BubbleMap } from './BubbleMap/index.js';
import { DateHistogram } from './DateHistogram/index.js';
import { extent, timeFormat } from 'd3';

const width = 960;
const height = 500;
const dateHistogramSize = 0.2;

const xValue = (d) => d.time;

const xAxisTickFormat = timeFormat('%m/%d/%y');

const App = () => {
  const worldAtlas = useWorldAtlas();
  const migrants = useMigrants();
  const [brushExtent, setBrushExtent] = useState();

  if (!worldAtlas || !migrants) {
    return <pre>Loading...</pre>;
  }

  const filteredMigrants = brushExtent
    ? migrants.filter((d) => {
        const date = xValue(d);
        return (
          date > brushExtent[0] && date < brushExtent[1]
        );
      })
    : migrants;

  return (
    <svg width={width} height={height}>
      <BubbleMap
        migrants={filteredMigrants}
        fullMigrants={migrants}
        worldAtlas={worldAtlas}
        xAxisTickFormat={xAxisTickFormat}
      />
      <g
        transform={`translate(0, ${
          height - dateHistogramSize * height
        })`}
      >
        <DateHistogram
          migrants={migrants}
          width={width}
          height={dateHistogramSize * height}
          setBrushExtent={setBrushExtent}
          xValue={xValue}
          xAxisTickFormat={xAxisTickFormat}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
